==> deepin-screen-recorder_5.8.1.orig.tar.xz: deepin-screen-recorder-5.8.1/translations/deepin-screen-recorder_bo.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bo">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>སྡེར་མའི་མཚོན་རྟགས་ལ་གནོན་རྒྱུ།
ཡང་ན་བརྙན་ཕབ་ཀྱི་མྱུར་མཐེབ་མནན་ནས་བརྙན་ཕབ་མཚམས་འཇོག་བྱ་རྒྱུ།</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>བརྙན་ཕབ།</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>བརྙན་བཤུས།</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>བརྙན་བཤུས་བརྙན་ཕབ།</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>ཉར་མི་ཐུབ་པས། མིག་སྔའི་སྤྱོད་མཁན་གྱི་དཀར་ཆག་འོག་ཏུ་ཉར་རོགས།</translation>
    </message>
    <message>
        <source>View</source>
        <translation>ལྟ་བ།</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>བརྙན་བཤུས་ཚར་བ།</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>ཁུལ་ཁོངས་འདེམས་པ།</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>ཉར་བ།</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>པར་%1དུ་ཉར་ཟིན།</translation>
    </message>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>བརྙན་བཤུས་བརྙན་ཕབ་སྐར་ཆ་%1རྗེས་སུ་འགོ་སློང་སྲིད།</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>སྣང་མེད།</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>དྲས་སྦྱར་པང་།</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>བརྙན་ཕབ་ཡིག་ཆ་ཉར་བཞིན་ཡོད་པས། སྒུག་རོགས་གནང་།</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>མི་བྱེད།</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>ཉར་བ།</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>ཕྱིར་འཐེན།</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>Screen Capture</source>
        <translation>བརྙན་བཤུས་བརྙན་ཕབ།</translation>
    </message>
    <message>
        <source>View</source>
        <translation>ལྟ་བ།</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>ཕབ་འཇུག་བྱས་ཟིན།</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>པར་%1དུ་ཉར་ཟིན།</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>བརྙན་བཤུས་བརྙན་ཕབ་སྐར་ཆ་%1རྗེས་སུ་འགོ་སློང་སྲིད།</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>འདིར་ཡིག་ཆ་སྣོན་རོགས་གནང་།</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>འགོ་སློང་།/བརྙན་བཤུས།</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>ཕྱིར་འཐེན།/ཉར་བ།</translation>
    </message>
    <message>
        <source>Drawing</source>
        <translation>རི་མོ་བྲི་བ།</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>ཁུལ་ཁོངས་སྙོམས་སྒྲིག</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>སྒྲིག་བཀོད།</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>བརྙན་བཤུས་མགྱོགས་མྱུར་འགོ་སློང་བ།</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>འོད་རྟགས་ཡོད་པའི་སྒེའུ་ཁུང་བརྙན་བཤུས་བྱེད་པ།</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>སྐར་ཆ་5འགྱངས་ནས་བརྙན་བཤུས་བྱེད་པ།</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>བརྙན་ཡོལ་ཡོངས་བཤུ་ལེན་བྱེད་པ།</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>དྲས་སྦྱར་པང་དུ་པར་སློག་བྱེད་པ།</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>ཕྱིར་འཐེན།</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>ཉར་བ།</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>གྲུ་བཞི་ནར་མོ།</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>འཇོང་དབྱིབས།</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>དྲང་ཕིག</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>པིར་སྨྱུག</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>ཡི་གེ།</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>བདམས་པའི་རི་མོ་སུབ་པ།</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>མི་བྱེད།</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>ཡར་འདེམས་ཁུལ་གྱི་མཐོ་ཚད་ཆེ་རུ་གཏོང་བ།</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>མར་འདེམས་ཁུལ་གྱི་མཐོ་ཚད་ཆེ་རུ་གཏོང་བ།</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>གཡོན་ཏུ་འདེམས་ཁུལ་གྱི་ཞེང་ཚད་ཆེ་རུ་གཏོང་བ།</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>གཡས་སུ་འདེམས་ཁུལ་གྱི་ཞེང་ཚད་ཆེ་རུ་གཏོང་བ།</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>ཡར་འདེམས་ཁུལ་གྱི་མཐོ་ཚད་ནུང་རུ་གཏོང་བ།</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>མར་འདེམས་ཁུལ་གྱི་མཐོ་ཚད་ཆུང་རུ་གཏོང་བ།</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>གཡོན་ཏུ་འདེམས་ཁུལ་གྱི་ཞེང་ཚད་ཆུང་རུ་གཏོང་བ།</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>གཡས་སུ་འདེམས་ཁུལ་གྱི་ཞེང་ཚད་ཆུང་རུ་གཏོང་བ།</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>རོགས་པ།</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>མྱུར་མཐེབ་གསལ་བ།</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>རབ་རིབ།</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>མོ་སའེ་ཁེ།</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>སྒྲ་ཕབ་ཁ་ཕྱེ།</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>སྐད་དུང་།</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>མ་ལག་སྒྲ་ཟློས།</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>སྒྲ་ཕབ་ཁ་རྒྱག</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>མཐེབ་གཅུས་མངོན་པ།</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>མཐེབ་གཅུས་ཡིབ་པ།</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>བརྙན་མིག་ཁ་ཕྱེ།</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>བརྙན་མིག་ཁ་རྒྱག</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>གནོན་པ་གསལ་བ།</translation>
    </message>
    <message>
        <source>Hide Click</source>
        <translation>གནོན་པ་ཡིབ་པ།</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>གདམ་ག</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>རྣམ་བཞག</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>ལྡེབ་གྲངས།</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>གྲུ་བཞི་ནར་མོ།</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>འཇོང་དབྱིབས།</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>དྲང་ཕིག</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>མདའ་རྟགས།</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>པིར་སྨྱུག</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>ཡི་གེ།</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>དུ་ཉར་བ།</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>ཅོག་ངོས།</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>པར་རིས།</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>དམིགས་བཙུགས་ས་གནས།</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>རྣམ་བཞག་ </translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>དྲས་སྦྱར་པང་།</translation>
    </message>
    <message>
        <source>Edit in Draw</source>
        <translation>བྲི་གདན་ཐོག་རྩོམ་སྒྲིག་བྱེད་པ།</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>འོད་རྟགས་གསལ་བ།</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Recordings</source>
        <translation>སྒྲ་ཕབ།</translation>
    </message>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>བརྙན་ཕབ་བྱེད་ནུས་གནས་སྐབས་སྤྱོད་མི་ཆོག</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>ཕྱིར་འཐེན།</translation>
    </message>
</context>
</TS>

==> deepin-screen-recorder_5.9.3.orig.tar.xz: deepin-screen-recorder-5.9.3/translations/deepin-screen-recorder_bo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="bo" version="2.1">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>སྡེར་མའི་མཚོན་རྟགས་ལ་གནོན་རྒྱུ།
ཡང་ན་བརྙན་ཕབ་ཀྱི་མྱུར་མཐེབ་མནན་ནས་བརྙན་ཕབ་མཚམས་འཇོག་བྱ་རྒྱུ།</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>བརྙན་ཕབ།</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>བརྙན་བཤུས།</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>བརྙན་བཤུས་བརྙན་ཕབ།</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>ཉར་མི་ཐུབ་པས། མིག་སྔའི་སྤྱོད་མཁན་གྱི་དཀར་ཆག་འོག་ཏུ་ཉར་རོགས།</translation>
    </message>
    <message>
        <source>View</source>
        <translation>ལྟ་བ།</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>བརྙན་བཤུས་ཚར་བ།</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>ཁུལ་ཁོངས་འདེམས་པ།</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>ཉར་བ།</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>པར་%1དུ་ཉར་ཟིན།</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>སྣང་མེད།</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>དྲས་སྦྱར་པང་།</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>བརྙན་ཕབ་ཡིག་ཆ་ཉར་བཞིན་ཡོད་པས། སྒུག་རོགས་གནང་།</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>ཕབ་བཟོ་བྱེད་པའི་བརྒྱུད་རིམ་ནང་སྒེའུ་ཁུང་གི་ཁྱད་ནུས་སྒོ་བརྒྱབ་པས། བརྙན་ལེན་མཚམས་བཞག་པ།</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>བརྙན་བཤུས།</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>མི་བྱེད།</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>ཉར་བ།</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>ཕྱིར་འཐེན།</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>ལྟ་བ།</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>ཕབ་འཇུག་བྱས་ཟིན།</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>པར་%1དུ་ཉར་ཟིན།</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>བརྙན་ཕབ།</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>བརྙན་བཤུས་བརྙན་ཕབ་སྐར་ཆ་%1རྗེས་སུ་འགོ་སློང་སྲིད།</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>འདིར་ཡིག་ཆ་སྣོན་རོགས་གནང་།</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>འགོ་སློང་།/བརྙན་བཤུས།</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>ཕྱིར་འཐེན།/ཉར་བ།</translation>
    </message>
    <message>
        <source>Drawing</source>
        <translation>རི་མོ་བྲི་བ།</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>ཁུལ་ཁོངས་སྙོམས་སྒྲིག</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>སྒྲིག་བཀོད།</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>བརྙན་བཤུས་མགྱོགས་མྱུར་འགོ་སློང་བ།</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>འོད་རྟགས་ཡོད་པའི་སྒེའུ་ཁུང་བརྙན་བཤུས་བྱེད་པ།</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>སྐར་ཆ་5འགྱངས་ནས་བརྙན་བཤུས་བྱེད་པ།</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>བརྙན་ཡོལ་ཡོངས་བཤུ་ལེན་བྱེད་པ།</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>ཕྱིར་འཐེན།</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>ཉར་བ།</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>གྲུ་བཞི་ནར་མོ།</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>འཇོང་དབྱིབས།</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>དྲང་ཕིག</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>པིར་སྨྱུག</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>ཡི་གེ།</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>བདམས་པའི་རི་མོ་སུབ་པ།</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>མི་བྱེད།</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>ཡར་འདེམས་ཁུལ་གྱི་མཐོ་ཚད་ཆེ་རུ་གཏོང་བ།</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>མར་འདེམས་ཁུལ་གྱི་མཐོ་ཚད་ཆེ་རུ་གཏོང་བ།</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>གཡོན་ཏུ་འདེམས་ཁུལ་གྱི་ཞེང་ཚད་ཆེ་རུ་གཏོང་བ།</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>གཡས་སུ་འདེམས་ཁུལ་གྱི་ཞེང་ཚད་ཆེ་རུ་གཏོང་བ།</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>ཡར་འདེམས་ཁུལ་གྱི་མཐོ་ཚད་ནུང་རུ་གཏོང་བ།</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>མར་འདེམས་ཁུལ་གྱི་མཐོ་ཚད་ཆུང་རུ་གཏོང་བ།</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>གཡོན་ཏུ་འདེམས་ཁུལ་གྱི་ཞེང་ཚད་ཆུང་རུ་གཏོང་བ།</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>གཡས་སུ་འདེམས་ཁུལ་གྱི་ཞེང་ཚད་ཆུང་རུ་གཏོང་བ།</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>རོགས་པ།</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>མྱུར་མཐེབ་གསལ་བ།</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>སྒྲ་འབེབས།</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>མཐེབ་གནོན།</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>བརྙན་མིག </translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>བརྙན་འབེབས་གང་མགྱོགས་འགོ་སློང་།</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>གདམ་ག</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>རབ་རིབ།</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>མོ་སའེ་ཁེ།</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>སྒྲ་ཕབ་ཁ་ཕྱེ།</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>སྐད་དུང་།</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>མ་ལག་སྒྲ་ཟློས།</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>སྒྲ་ཕབ་ཁ་རྒྱག</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>མཐེབ་གཅུས་མངོན་པ།</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>མཐེབ་གཅུས་ཡིབ་པ།</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>བརྙན་མིག་ཁ་ཕྱེ།</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>བརྙན་མིག་ཁ་རྒྱག</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>གནོན་པ་གསལ་བ།</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>གདམ་ག</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>རྣམ་བཞག</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>ལྡེབ་གྲངས།</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>གྲུ་བཞི་ནར་མོ།</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>འཇོང་དབྱིབས།</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>དྲང་ཕིག</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>མདའ་རྟགས།</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>པིར་སྨྱུག</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>ཡི་གེ།</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>དུ་ཉར་བ།</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>ཅོག་ངོས།</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>པར་རིས།</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>དམིགས་བཙུགས་ས་གནས།</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>རྣམ་བཞག་ </translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>དྲས་སྦྱར་པང་།</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>འོད་རྟགས་གསལ་བ།</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation>ཕབ་བཟོ་ཁུལ་ཁོངས་ཀྱི་ཁྱབ་ཁོངས་%1*%2ནང་ཚུན་ལེགས་སྒྲིག་བྱས་ན། བརྙན་འཕྲིན་གྱི་གྲུབ་འབྲས་དེ་བས་ཡག </translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Recordings</source>
        <translation>སྒྲ་ཕབ།</translation>
    </message>
</context>
</TS>
